@@ -2,14 +2,12 @@
 
 """
    Usage: sync.py [<product> | <language-code>]
-   Note that PYTHON and I18NDUDE must have been set as enviroment variables before calling this script
 """
 
 import os, sys
 from utils import getPoFilesAsCmdLine, getPoFilesByLanguageCode, getProduct, getPotFiles, getLongProductName
 
-__PYTHON = os.environ.get('PYTHON', '')
-__I18NDUDE = os.environ.get('I18NDUDE', '')
+__I18NDUDE = os.environ.get('I18NDUDE', 'i18ndude')
 
 def main():
     if len(sys.argv) == 1:
@@ -28,7 +26,7 @@ def main():
             for po in poFiles:
                 for pot in potFiles:
                     if getProduct(po) == getProduct(pot):
-                        os.system(__PYTHON + ' ' + __I18NDUDE + (' sync --pot %s %s') % (pot, po))
+                        os.system(__I18NDUDE + (' sync --pot %s %s') % (pot, po))
         else:
             print 'Neither a pot nor po files for the given argument were found.'
             sys.exit(3)
@@ -39,7 +37,7 @@ def main():
             print 'No po-files were found for the given product.'
             sys.exit(4)
 
-        os.system(__PYTHON + ' ' + __I18NDUDE + (' sync --pot %s %s') % (pot, poFiles))
+        os.system(__I18NDUDE + (' sync --pot %s %s') % (pot, poFiles))
 
 if __name__ == '__main__':
     main()
